@@ -39,9 +39,11 @@ struct _PangoCairoCoreTextFontMap
 {
   PangoCoreTextFontMap parent_instance;
 
+  guint serial;
   gdouble dpi;
 };
 
+_PANGO_EXTERN
 GType pango_cairo_core_text_font_map_get_type (void) G_GNUC_CONST;
 
 PangoCoreTextFont *
